==> jaysonic-1.3.3.tgz: package/lib/ServerProtocol.js <==
"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var _require = require("./buffer"),
    MessageBuffer = _require.MessageBuffer;

var TCPServerProtocol =
/*#__PURE__*/
function () {
  function TCPServerProtocol(client, delimiter) {
    _classCallCheck(this, TCPServerProtocol);

    this.client = client;
    this.factory = null;
    this.delimiter = delimiter;
    this.messageBuffer = new MessageBuffer(delimiter);
  }

  _createClass(TCPServerProtocol, [{
    key: "clientConnected",
    value: function clientConnected() {
      var _this = this;

      this.client.on("data", function (data) {
        _this.messageBuffer.push(data);

        while (!_this.messageBuffer.isFinished()) {
          var chunk = _this.messageBuffer.handleData();

          Promise.all(_this.factory.handleValidation(chunk)).then(function (validationResult) {
            var message = validationResult[1];

            if (message.batch) {
              _this.client.write(JSON.stringify(message.batch) + _this.delimiter);
            } else if (message.notification) {
              _this.factory.emit("notify", message.notification);
            } else {
              _this.factory.getResult(message).then(function (result) {
                return _this.client.write(result + _this.delimiter);
              })["catch"](function (error) {
                return _this.client.write(JSON.stringify(error) + _this.delimiter);
              });
            }
          })["catch"](function (error) {
            return _this.client.write(JSON.stringify(error) + _this.delimiter);
          });
        }
      });
      this.client.on("close", function () {
        _this.factory.emit("clientDisconnected", _this.client);
      });
      this.client.on("end", function () {
        _this.factory.emit("clientDisconnected", _this.client);
      });
    }
  }]);

  return TCPServerProtocol;
}();

var WSServerProtocol =
/*#__PURE__*/
function () {
  function WSServerProtocol(client, delimiter) {
    _classCallCheck(this, WSServerProtocol);

    this.client = client;
    this.factory = null;
    this.delimiter = delimiter;
    this.messageBuffer = new MessageBuffer(delimiter);
  }

  _createClass(WSServerProtocol, [{
    key: "clientConnected",
    value: function clientConnected() {
      var _this2 = this;

      this.client.on("message", function (data) {
        _this2.messageBuffer.push(data);

        while (!_this2.messageBuffer.isFinished()) {
          var chunk = _this2.messageBuffer.handleData();

          Promise.all(_this2.factory.handleValidation(chunk)).then(function (validationResult) {
            var message = validationResult[1];

            if (message.batch) {
              _this2.client.send(JSON.stringify(message.batch) + _this2.delimiter);
            } else if (message.notification) {
              _this2.factory.emit("notify", message.notification);
            } else {
              _this2.factory.getResult(message).then(function (result) {
                return _this2.client.send(result + _this2.delimiter);
              })["catch"](function (error) {
                return _this2.client.send(JSON.stringify(error) + _this2.delimiter);
              });
            }
          })["catch"](function (error) {
            return _this2.client.send(JSON.stringify(error) + _this2.delimiter);
          });
        }
      });
      this.client.on("close", function () {
        _this2.factory.emit("clientDisconnected", _this2.client);
      });
      this.client.on("end", function () {
        _this2.factory.emit("clientDisconnected", _this2.client);
      });
    }
  }]);

  return WSServerProtocol;
}();

var HttpServerProtocol =
/*#__PURE__*/
function () {
  function HttpServerProtocol(request, response, delimiter) {
    _classCallCheck(this, HttpServerProtocol);

    this.client = request;
    this.response = response;
    this.delimiter = delimiter;
    this.factory = null;
    this.messageBuffer = new MessageBuffer(delimiter);
  }

  _createClass(HttpServerProtocol, [{
    key: "clientConnected",
    value: function clientConnected() {
      var _this3 = this;

      this.client.on("data", function (data) {
        _this3.messageBuffer.push(data);
      });
      this.client.on("end", function () {
        while (!_this3.messageBuffer.isFinished()) {
          var chunk = _this3.messageBuffer.handleData();

          Promise.all(_this3.factory.handleValidation(chunk)).then(function (validationResult) {
            var message = validationResult[1];

            if (message.batch) {
              _this3.factory.setResponseHeader({
                response: _this3.response
              });

              _this3.response.write(JSON.stringify(message.batch) + _this3.delimiter, function () {
                _this3.response.end();
              });
            } else if (message.notification) {
              _this3.factory.setResponseHeader({
                response: _this3.response,
                notification: true
              });

              _this3.response.end();
            } else {
              _this3.factory.getResult(message).then(function (result) {
                _this3.factory.setResponseHeader({
                  response: _this3.response
                });

                _this3.response.write(result + _this3.delimiter, function () {
                  _this3.response.end();
                });
              })["catch"](function (error) {
                _this3.factory.setResponseHeader({
                  response: _this3.response,
                  errorCode: error.error.code
                });

                _this3.response.write(JSON.stringify(error) + _this3.delimiter, function () {
                  _this3.response.end();
                });
              });
            }
          })["catch"](function (error) {
            _this3.factory.setResponseHeader({
              response: _this3.response,
              errorCode: error.code
            });

            _this3.response.write(JSON.stringify(error) + _this3.delimiter, function () {
              _this3.response.end();
            });
          });
        }
      });
    }
  }]);

  return HttpServerProtocol;
}();

module.exports = {
  TCPServerProtocol: TCPServerProtocol,
  WSServerProtocol: WSServerProtocol,
  HttpServerProtocol: HttpServerProtocol
};

==> jaysonic-2.0.1.tgz: package/lib/ServerProtocol.js <==
"use strict";

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var _require = require("./buffer"),
    MessageBuffer = _require.MessageBuffer;

var TCPServerProtocol =
/*#__PURE__*/
function () {
  function TCPServerProtocol(factory, client, delimiter) {
    _classCallCheck(this, TCPServerProtocol);

    this.client = client;
    this.factory = factory;
    this.delimiter = delimiter;
    this.messageBuffer = new MessageBuffer(delimiter);
  }

  _createClass(TCPServerProtocol, [{
    key: "clientConnected",
    value: function clientConnected() {
      var _this = this;

      this.client.on("data", function (data) {
        _this.messageBuffer.push(data);

        while (!_this.messageBuffer.isFinished()) {
          var chunk = _this.messageBuffer.handleData();

          _this.factory.handleValidation(chunk).then(function (message) {
            if (message.batch) {
              if (message.batch.empty) {
                return;
              }

              _this.client.write(JSON.stringify(message.batch) + _this.delimiter);
            } else if (message.notification) {
              _this.factory.emit(message.notification.method, message.notification);
            } else {
              _this.factory.getResult(message).then(function (result) {
                return _this.client.write(result);
              })["catch"](function (error) {
                _this.client.write(error);
              });
            }
          })["catch"](function (error) {
            _this.client.write(error.message);
          });
        }
      });
      this.client.on("close", function () {
        _this.factory.emit("clientDisconnected", _this.client);
      });
      this.client.on("end", function () {
        _this.factory.emit("clientDisconnected", _this.client);
      });
    }
  }]);

  return TCPServerProtocol;
}();

var WSServerProtocol =
/*#__PURE__*/
function () {
  function WSServerProtocol(factory, client, delimiter) {
    _classCallCheck(this, WSServerProtocol);

    this.client = client;
    this.factory = factory;
    this.delimiter = delimiter;
    this.messageBuffer = new MessageBuffer(delimiter);
  }

  _createClass(WSServerProtocol, [{
    key: "clientConnected",
    value: function clientConnected() {
      var _this2 = this;

      this.client.on("message", function (data) {
        _this2.messageBuffer.push(data);

        while (!_this2.messageBuffer.isFinished()) {
          var chunk = _this2.messageBuffer.handleData();

          _this2.factory.handleValidation(chunk).then(function (message) {
            if (message.batch) {
              if (message.batch.empty) {
                return;
              }

              _this2.client.send(JSON.stringify(message.batch) + _this2.delimiter);
            } else if (message.notification) {
              _this2.factory.emit(message.notification.method, message.notification);
            } else {
              _this2.factory.getResult(message).then(function (result) {
                return _this2.client.send(result);
              })["catch"](function (error) {
                _this2.client.send(error);
              });
            }
          })["catch"](function (error) {
            _this2.client.send(error.message);
          });
        }
      });
      this.client.on("close", function () {
        _this2.factory.emit("clientDisconnected", _this2.client);
      });
      this.client.on("end", function () {
        _this2.factory.emit("clientDisconnected", _this2.client);
      });
    }
  }]);

  return WSServerProtocol;
}();

var HttpServerProtocol =
/*#__PURE__*/
function () {
  function HttpServerProtocol(factory, request, response, delimiter) {
    _classCallCheck(this, HttpServerProtocol);

    this.client = request;
    this.response = response;
    this.delimiter = delimiter;
    this.factory = factory;
    this.messageBuffer = new MessageBuffer(delimiter);
  }

  _createClass(HttpServerProtocol, [{
    key: "clientConnected",
    value: function clientConnected() {
      var _this3 = this;

      this.client.on("data", function (data) {
        _this3.messageBuffer.push(data);
      });
      this.client.on("end", function () {
        while (!_this3.messageBuffer.isFinished()) {
          var chunk = _this3.messageBuffer.handleData();

          _this3.factory.handleValidation(chunk).then(function (message) {
            if (message.batch) {
              if (message.batch.empty) {
                return;
              }

              _this3.factory.setResponseHeader({
                response: _this3.response
              });

              _this3.response.write(JSON.stringify(message.batch) + _this3.delimiter, function () {
                _this3.response.end();
              });
            } else if (message.notification) {
              _this3.factory.setResponseHeader({
                response: _this3.response,
                notification: true
              });

              _this3.response.end();
            } else {
              _this3.factory.getResult(message).then(function (result) {
                _this3.factory.setResponseHeader({
                  response: _this3.response
                });

                _this3.response.write(result, function () {
                  _this3.response.end();
                });
              })["catch"](function (error) {
                _this3.sendError(error);
              });
            }
          })["catch"](function (error) {
            _this3.sendError(error.message);
          });
        }
      });
    }
  }, {
    key: "sendError",
    value: function sendError(error) {
      var _this4 = this;

      this.factory.setResponseHeader({
        response: this.response,
        errorCode: JSON.parse(error).error.code || 500
      });
      this.response.write(error, function () {
        _this4.response.end();
      });
    }
  }]);

  return HttpServerProtocol;
}();

module.exports = {
  TCPServerProtocol: TCPServerProtocol,
  WSServerProtocol: WSServerProtocol,
  HttpServerProtocol: HttpServerProtocol
};
